Implementations for various factorization algorithms

Functions

This function implements Shanks’s square forms factorization (SQUFOF). It will assume that target is not a perfect square and the multiplier is square-free.

Find factors by trial division. The target is guaranteed fully factored only if bound() * bound() > target. The parameter limit sets the max prime to be tried aside from bound() Return the found factors and the residual. The residual will be Ok(1) or Ok(p) if fully factored.